@@ -9,6 +9,7 @@ from fso_metadata.format_request import dict_to_string
 
 def get_codelist(
     identifier: str,
+    environment: str = "PRD",
     export_format: str = "SDMX-ML",
     version_format: float = 2.1,
     annotations: bool = False,
@@ -17,6 +18,8 @@ def get_codelist(
     Get a codelist based on an identifier
     Parameters:
         - identifier (str): the codelist's identifier
+        - environment (str, default="PRD"): environment to call
+            Available are 'PRD', 'ABN', 'TEST', 'QA' and 'DEV'.
         - export_format (str, default="SDMX-ML"): the export's format
            Available are CSV, XLSX, SDMX-ML or JSON.
         - version_format (float, default=2.1): the export format's version
@@ -30,6 +33,7 @@ def get_codelist(
     """
     api = Api(
         api_type="codelist",
+        environment=environment,
         _id=identifier,
         export_format=export_format,
         version_format=version_format,
@@ -42,24 +46,34 @@ def get_codelist(
     return res
 
 
-def get_data_structure(identifier: str, language: str = "fr") -> dict:
+def get_data_structure(
+    identifier: str, 
+    environment: str = "PRD", 
+    language: str = "fr"
+) -> dict:
     """
     Get the data structure
     Parameters:
         - identifier (str): the dataset's identifier
+        - environment (str, default="PRD"): environment to call
+            Available are 'PRD', 'ABN', 'TEST', 'QA' and 'DEV'.
         - language (str, default='fr'): the language of the response data
             Available are 'fr', 'de', 'it', 'en'.
     Returns:
         - response: datastructure dictionnary
     """
     api = Api(
-        api_type="dcat_data_structure", _id=identifier, language=language
+        api_type="dcat_data_structure", 
+        environment=environment, 
+        _id=identifier, 
+        language=language
     )
     return api.get_response()
 
 
 def get_nomenclature_one_level(
     identifier: str,
+    environment: str = "PRD",
     level_number: int,
     filters: dict = {},
     language: str = "fr",
@@ -69,6 +83,8 @@ def get_nomenclature_one_level(
     Get one level of a nomenclature
     Parameters:
         - identifier (str): nomenclature's identifier
+        - environment (str, default="PRD"): environment to call
+            Available are 'PRD', 'ABN', 'TEST', 'QA' and 'DEV'.
         - level_number (int): level to export
         - filter (default={}): additionnal filters
         - language (str, default='fr'): response data's language
@@ -86,6 +102,7 @@ def get_nomenclature_one_level(
     )
     api = Api(
         api_type="nomenclature_one_level",
+        environment=environment,
         _id=identifier,
         parameters=parameters,
         export_format="CSV",
@@ -95,6 +112,7 @@ def get_nomenclature_one_level(
 
 def get_nomenclature_multiple_levels(
     identifier: str,
+    environment: str = "PRD",
     level_from: int,
     level_to: int,
     filters: dict = {},
@@ -106,6 +124,8 @@ def get_nomenclature_multiple_levels(
     Get multiple levels of a nomenclature (from `level_from` to `level_to`)
     Parameters:
         - identifier (str): nomenclature's identifier
+        - environment (str, default="PRD"): environment to call
+            Available are 'PRD', 'ABN', 'TEST', 'QA' and 'DEV'.
         - level_from (int): the 1st level to include
         - level_to (int): the last level to include
         - filter (default={}): additionnal filters
@@ -127,6 +147,7 @@ def get_nomenclature_multiple_levels(
     )
     api = Api(
         api_type="nomenclature_multiple_levels",
+        environment=environment,
         _id=identifier,
         parameters=parameters,
         export_format="CSV",
