@@ -16,7 +16,7 @@ class Api:
         api_type: str,
         *,
         export_format: str = "JSON",
-        root_url: str = BASE_URL,
+        environment: str = "PRD",
         parameters: Union[str, dict] = None,
         _id: str = None,
         language: str = "en",
@@ -27,8 +27,8 @@ class Api:
         - api_type (str): the name of the api to call (see url_mapping)
         - export_format (str, default="JSON"): the export's format
            Available are CSV, XLSX, SDMX-ML and JSON.
-        - root_url (str, default=BASE_URL): root url to call
-            (for i14y or dcat)
+        - environment (str, default="PRD"): environment to call
+            Available are 'PRD', 'ABN', 'TEST', 'QA' and 'DEV'.
         - parameters (Union[str, dict]): additional request parameters
         - _id: the identifier or id of the request's object
         - language (str, default='en'): the language of the response data
@@ -36,7 +36,7 @@ class Api:
         - version_format (float, default=2.1): the export format's version
           (2.0 or 2.1 when format is SDMX-ML) (for 'codelist')
         """
-        self.root_url = root_url
+        self.environment = ENVIRONMENTS[environment]
         self.export_format = export_format
         self.parameters = parameters
 
@@ -55,7 +55,7 @@ class Api:
         """
         request_function = REQUEST_FUNCTION_MAPPING[self.export_format]
         return request_function(
-            f"{self.root_url}/api/{self.api_url}", self.parameters
+            f"{self.environment}/api/{self.api_url}", self.parameters
         )
 
     def get_url(
